@@ -4,6 +4,10 @@
 // Class: Battle
 //
 
+#include <lslutils/misc.h>
+#include <lslutils/conversion.h>
+#include "battle.h"
+
 #include <wx/timer.h>
 #include <wx/image.h>
 #include <wx/string.h>
@@ -11,14 +15,9 @@
 #include <wx/filename.h>
 #include <wx/file.h>
 
-#include <lslutils/conversion.h>
 
-#include "battle.h"
-#include "gui/ui.h"
-#include "iserver.h"
 #include "user.h"
 #include "utils/conversion.h"
-#include <lslutils/misc.h>
 #include "utils/uievents.h"
 #include "utils/battleevents.h"
 #include "utils/slpaths.h"
@@ -30,7 +29,10 @@
 #include "spring.h"
 #include "utils/conversion.h"
 #include "utils/globalevents.h"
+#include "autohostmanager.h"
 #include "log.h"
+#include "iserver.h"
+#include "gui/ui.h"
 
 
 const unsigned int TIMER_INTERVAL         = 1000;
@@ -49,6 +51,8 @@ Battle::Battle( IServer& serv, int id ) :
         m_id( id ),
 		m_timer(NULL)
 {
+	m_autohost_manager = new AutohostManager(); //FIXME: don't instantiate for each battle, only for the battle we've joined
+	m_autohost_manager->SetBattle(this);
 	ConnectGlobalEvent(this, GlobalEvent::OnUnitsyncReloaded, wxObjectEventFunction(&Battle::OnUnitsyncReloaded));
     m_opts.battleid =  m_id;
 }
@@ -60,6 +64,8 @@ Battle::~Battle()
 		delete m_timer;
 		m_timer = NULL;
 	}
+	delete m_autohost_manager;
+	m_autohost_manager = NULL;
 }
 
 
@@ -598,12 +604,12 @@ void Battle::UserPositionChanged( const User& user )
 	  m_serv.SendUserPosition( user );
 }
 
-
+/*
 void Battle::SendScriptToClients()
 {
 	m_serv.SendScriptToClients(TowxString(GetScript()));
 }
-
+*/
 
 void Battle::StartHostedBattle()
 {
