@@ -87,7 +87,7 @@ public:
 	virtual void Autobalance( BalanceType balance_type = balance_divide, bool clans = true, bool strong_clans = true, int allyteamsize = 0 );
 	virtual void FixTeamIDs( BalanceType balance_type = balance_divide, bool clans = true, bool strong_clans = true, int controlteamsize = 0 );
 
-	virtual void SendScriptToClients();
+//	virtual void SendScriptToClients();
 
 	virtual bool CheckBan(User &user);
 
