@@ -181,7 +181,7 @@ static size_t write_streamed_data(const void* tmp, size_t size, size_t nmemb,CSd
 		}
 		if (sdp->skipped==LENGTH_SIZE) { // length bytes read
 			const int towrite=intmin ((*sdp->list_it)->compsize-sdp->file_pos ,  //minimum of bytes to write left in file and bytes to write left in buf
-					    buf_end-buf_pos);
+									  buf_end-buf_pos);
 			if (towrite<0) {
 				LOG_ERROR("Fatal, something went wrong here! %d, %d %d", towrite, buf_end, buf_pos);
 				return -1;
@@ -200,7 +200,7 @@ static size_t write_streamed_data(const void* tmp, size_t size, size_t nmemb,CSd
 				sdp->file_handle = NULL;
 				if (!fileSystem->fileIsValid(*sdp->list_it,sdp->file_name.c_str())) {
 					LOG_ERROR("File is broken?!: %s",sdp->file_name.c_str());
-					remove(sdp->file_name.c_str());
+					fileSystem->removeFile(sdp->file_name.c_str());
 					return -1;
 				}
 				sdp->list_it++;
@@ -217,7 +217,7 @@ static size_t write_streamed_data(const void* tmp, size_t size, size_t nmemb,CSd
 	draw a nice download status-bar
 */
 static int progress_func(CSdp& csdp, double TotalToDownload, double NowDownloaded,
-			 double TotalToUpload, double NowUploaded)
+						 double TotalToUpload, double NowUploaded)
 {
 
 	(void)csdp;
@@ -234,7 +234,7 @@ static int progress_func(CSdp& csdp, double TotalToDownload, double NowDownloade
 	for ( std::map<CSdp*,uint64_t>::iterator it = csdp.m_download->map_rapid_progress.begin(); it != csdp.m_download->map_rapid_progress.end(); it++ ) {
 		total += (*it).second;
 	}
-	csdp.m_download->rapid_progress = total;
+	csdp.m_download->progress = total;
 	if (TotalToDownload == NowDownloaded) //force output when download is finished
 		LOG_PROGRESS(NowDownloaded,TotalToDownload, true);
 	else
