@@ -2,7 +2,7 @@
 
 #ifndef CONTENTSEARCHRESULTSLISTCTRL_H
 #define CONTENTSEARCHRESULTSLISTCTRL_H
-#include "../customvirtlistctrl.h"
+#include "gui/customvirtlistctrl.h"
 #include "contentsearchresult.h"
 
 class ContentSearchResultsListctrl : public CustomVirtListCtrl<ContentSearchResult*,ContentSearchResultsListctrl >
@@ -27,7 +27,7 @@ public:
 		WIDGETLISTCTRL_ID
 	};
 	int CompareOneCrit( DataType u1, DataType u2, int col, int dir ) const;
-protected:
+private:
 	DECLARE_EVENT_TABLE()
 };
 
