@@ -14,7 +14,6 @@
 #include <stdexcept>
 #include <vector>
 
-#include <lslunitsync/unitsync.h>
 
 #include "battleroomlistctrl.h"
 #include "iconimagelist.h"
@@ -32,6 +31,8 @@
 #include "log.h"
 #include "utils/lslconversion.h"
 
+#include <lslunitsync/unitsync.h>
+
 
 template<> SortOrder CustomVirtListCtrl<User*,BattleroomListCtrl>::m_sortorder = SortOrder();
 
@@ -84,26 +85,26 @@ BattleroomListCtrl::BattleroomListCtrl( wxWindow* parent, IBattle* battle, bool
 	wxListItem col;
 
 	int count = 0;
-    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _T("Status"), _T("Player/Bot") );
+    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _("Status"), _T("Player/Bot") );
 	m_status_column_index = count;
 	count++;
 	if ( m_showingame )
 	{
-        AddColumn( count, 55, _T("Ingame"), _T("Battleroom status") );
+        AddColumn( count, 55, _("Ingame"), _T("Battleroom status") );
 		m_ingame_column_index = count;
         count++;
     }
 
-    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _T("Faction"), _T("Faction icon") );
+    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _("Faction"), _T("Faction icon") );
 	m_faction_column_index = count;
 	count++;
-    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _T("Colour"), _T("Teamcolour") );
+    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _("Colour"), _T("Teamcolour") );
 	m_colour_column_index = count;
 	count++;
-    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _T("Country"), _T("Country") );
+    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _("Country"), _T("Country") );
 	m_country_column_index = count;
 	count++;
-    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _T("Rank"), _T("Rank") );
+    AddColumn( count, wxLIST_AUTOSIZE_USEHEADER, _("Rank"), _T("Rank") );
 	m_rank_column_index = count;
 	count++;
     AddColumn( count, 165, _("Nickname"), _T("Ingame name"));
@@ -876,20 +877,20 @@ void BattleroomListCtrl::OnUserMenuCreateGroup( wxCommandEvent& /*unused*/ )
 
 wxString BattleroomListCtrl::GetSelectedUserNick()
 {
-    if ( m_selected_index < 0 || m_selected_index >= (long)m_data.size() )
+    if (GetSelectedIndex() < 0)
         return wxEmptyString;
     else
-        return TowxString(m_data[m_selected_index]->GetNick());
+        return TowxString(m_data[GetSelectedIndex()]->GetNick());
 }
 
 void BattleroomListCtrl::OnActivateItem( wxListEvent& /*unused*/ )
 {
     if ( m_ro )
         return;
-    if ( m_selected_index < 0 || m_selected_index >= (long)m_data.size() )
+    if ( GetSelectedIndex() < 0)
         return;
 
-    const User* usr = m_data[m_selected_index];
+    const User* usr = m_data[GetSelectedIndex()];
     if ( usr != NULL && !usr->BattleStatus().IsBot() )
         ui().mw().OpenPrivateChat( *usr );
 }
