@@ -54,6 +54,7 @@
 #include "autohost.h"
 #include "log.h"
 #include "utils/lslconversion.h"
+#include "autohostmanager.h"
 
 BEGIN_EVENT_TABLE( BattleRoomTab, wxPanel )
 
@@ -378,11 +379,11 @@ void BattleRoomTab::UpdateBattleInfo()
 	if ( !m_battle ) return;
 	m_lock_chk->SetValue( m_battle->IsLocked() );
 	m_minimap->UpdateMinimap();
-	UpdateMapInfoSummary();
 	OptionListMap::iterator it;
 	for(it = m_opt_list_map.begin(); it != m_opt_list_map.end(); ++it) {
 		UpdateBattleInfo(it->first);
 	}
+	UpdateMapInfoSummary();
 }
 
 void BattleRoomTab::PrintAllySetup()
@@ -604,7 +605,7 @@ void BattleRoomTab::OnStart( wxCommandEvent& /*unused*/ )
 		}
 		else
 		{
-			autohostManager.GetAutohostHandler().Start();
+			m_battle->m_autohost_manager->GetAutohostHandler().Start();
 			//customMessageBoxNoModal( SL_MAIN_ICON, _("Host is not ingame."), _("Error") );
 		}
 	}
@@ -953,7 +954,7 @@ void BattleRoomTab::OnSavePreset( wxCommandEvent& /*unused*/ )
 {
 	if ( !m_battle ) return;
 	wxString presetname;
-	if ( !ui().AskText( _( "Enter preset name" ), _( "Enter a name to save the current set of options\nIf a preset with the same name already exist, it will be overwritten" ), presetname ) )
+	if ( !ui().AskText( _( "Enter a name to save the current set of options\nIf a preset with the same name already exist, it will be overwritten" ), _( "Enter preset name" ), presetname ) )
 		return;
 	if ( presetname.IsEmpty() )
 	{
@@ -993,7 +994,7 @@ void BattleRoomTab::OnMapBrowse( wxCommandEvent& /*unused*/ )
 	{
 		if ( !m_battle->IsFounderMe() )
 		{
-            autohostManager.GetAutohostHandler().SetMap(mapname);
+			m_battle->m_autohost_manager->GetAutohostHandler().SetMap(STD_STRING(mapname));
 			//m_battle->DoAction( _T( "suggests " ) + mapname );
 			return;
 		}
@@ -1033,7 +1034,8 @@ void BattleRoomTab::OnMapSelect( wxCommandEvent& /*unused*/ )
 	{
 		try
 		{
-			autohostManager.GetAutohostHandler().SetMap(m_map_combo->GetString(m_map_combo->GetCurrentSelection()));
+			const std::string map = STD_STRING(m_map_combo->GetString(m_map_combo->GetCurrentSelection()));
+			m_battle->m_autohost_manager->GetAutohostHandler().SetMap(map);
             //m_battle->DoAction( _T( "suggests " ) + TowxString(LSL::usync().GetMap( m_map_combo->GetCurrentSelection() ).name));
 		}
 		catch ( ... )
@@ -1111,7 +1113,6 @@ void BattleRoomTab::SetBattle(IBattle* battle)
 	m_minimap->SetBattle( m_battle );
 	m_players->SetBattle( m_battle );
 	m_chat->SetBattle( m_battle );
-	autohostManager.SetBattle(m_battle);
 
 	m_players->Clear();
 
@@ -1194,8 +1195,6 @@ void BattleRoomTab::OnBattleActionEvent( UiEvents::UiEventData data )
 	wxString msg = data.Count() > 1 ? data[1] : wxString(wxEmptyString);
 	GetChatPanel().DidAction( nick, msg );
 
-	if(autohostManager.GetAutohostType()==AutohostManager::AUTOHOSTTYPE_NONE)
-		autohostManager.RecnognizeAutohost(nick, msg);
 }
 
 void BattleRoomTab::OnHostNew( wxCommandEvent& /*event*/ )
