@@ -165,7 +165,7 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
     m_main_sizer->Add( m_misc_gui_sizer , 0, wxALL, 5 );
 
     wxStaticBoxSizer* m_start_tab_sizer = new wxStaticBoxSizer ( wxHORIZONTAL, this, _("Start tab") );
-    m_start_tab = new wxChoice( this, -1,  wxDefaultPosition, wxDefaultSize, MainWindow::GetTabNames() );
+    m_start_tab = new wxChoice( this, -1,  wxDefaultPosition, wxDefaultSize, ui().mw().GetTabNames() );
     m_start_tab->SetSelection( cfg().ReadLong(_T( "/GUI/StartTab" )) );
     wxStaticText* m_start_tab_label = new wxStaticText ( this, -1, _("Select which tab to show at startup") );
     m_start_tab_sizer->Add( m_start_tab_label  , 0, wxALIGN_CENTER_VERTICAL | wxEXPAND | wxALL, 5 );
