@@ -71,7 +71,7 @@ SLCONFIG("/Chat/BroadcastEverywhere",true, "setting to spam the server messages
 SLCONFIG("/Server/Autoconnect", false, "Connect to server on startup");
 
 static unsigned int s_reconnect_delay_ms = 6 * 1000; //initial reconnect delay
-static const unsigned int s_max_reconnect_delay = 120 * 1000; //max delay for reconnecting
+static const unsigned int s_max_reconnect_delay = 240 * 1000; //max delay for reconnecting
 
 Ui& ui()
 {
@@ -177,7 +177,7 @@ void Ui::Connect()
 void Ui::Reconnect()
 {
 	if (s_reconnect_delay_ms <= s_max_reconnect_delay) {
-		s_reconnect_delay_ms += 1000;
+		s_reconnect_delay_ms += std::max<unsigned int>(s_max_reconnect_delay * 0.50, 1000);
 	}
 	const wxString servname = sett().GetDefaultServer();
 	const wxString pass  = sett().GetServerAccountPass(servname);
@@ -542,17 +542,6 @@ void Ui::OnDisconnected( IServer& server, bool wasonline )
 	m_connect_retries--;
 }
 
-wxString Ui::GetNextServer()
-{
-	wxString previous_server = m_last_used_backup_server;
-	if ( previous_server.IsEmpty() ) previous_server = sett().GetDefaultServer();
-	wxArrayString serverlist = sett().GetServers();
-	int position = serverlist.Index( previous_server );
-	if ( position == wxNOT_FOUND ) position = -1;
-	position = ( position + 1) % serverlist.GetCount(); // switch to next in the list
-	return serverlist[position];
-}
-
 //! @brief Called when client has joined a channel
 //!
 //! @todo Check if a pannel allready exists for this channel
@@ -997,15 +986,13 @@ bool Ui::StartUpdate(const std::string& latestVersion)
 	}
 	if ( wxDirExists( updatedir ) ) {
 		if (!SlPaths::RmDir(STD_STRING(updatedir))) {
-			customMessageBox(SL_MAIN_ICON, _("Couldn't cleanup ") + TowxString(updatedir), _("Error"));
-			return false;
+			wxLogError(_T("Couldn't cleanup ") + TowxString(updatedir));
 		}
 	}
 	if ( !wxMkdir( updatedir ) ){
-		wxLogError( _T("couldn't create update directory") );
-		customMessageBox(SL_MAIN_ICON, _("Unable to create to the lobby update directory:") + TowxString(updatedir), _("Error"));
-		return false;
+		wxLogError( _T("couldn't create update directory") + TowxString(updatedir) );
 	}
+
 	if ( !wxFileName::IsDirWritable( updatedir ) ) {
 		wxLogError( _T("dir not writable: ") + updatedir );
 		customMessageBox(SL_MAIN_ICON, _("Unable to write to the lobby update directory:") + TowxString(updatedir), _("Error"));
