@@ -17,12 +17,12 @@ lsl/battle/ibattle.h
 **/
 
 #include <lslunitsync/data.h>
-#include <lslunitsync/optionswrapper.h>
 #include <lsl/battle/tdfcontainer.h>
 
 #include "user.h"
 #include "userlist.h"
 #include "utils/mixins.h"
+#include <lslunitsync/optionswrapper.h>
 
 const unsigned int DEFAULT_SERVER_PORT = 8452;
 const unsigned int DEFAULT_EXTERNAL_UDP_SOURCE_PORT = 16941;
@@ -30,6 +30,10 @@ const unsigned int DEFAULT_EXTERNAL_UDP_SOURCE_PORT = 16941;
 class IBattle;
 class IServer;
 class AutoHost;
+class AutohostManager;
+namespace LSL {
+	class OptionsWrapper;
+};
 
 struct BattleStartRect {
 	BattleStartRect() :
@@ -552,6 +556,7 @@ public:
 	virtual void RingNotSyncedAndNotReadyPlayers() {}
 	virtual void SetAutoLockOnStart(bool /*autolock*/) {}
 
+	AutohostManager* m_autohost_manager;
 protected:
 	BattleOptions m_opts;
 	bool m_generating_script;
