@@ -10,18 +10,17 @@
 #include "iserver.h"
 #include "socket.h"
 #include "battle.h"
-#include "channel/channel.h"
+#include "channel.h"
 #include "user.h"
 #include "utils/conversion.h"
-#include "chatpanel.h"
+#include "gui/chatpanel.h"
 #include "log.h"
 
 IServer::IServer():
 battles_iter(new BattleList_Iter(&m_battles)),
-m_keepalive(15),
 m_pass_hash(false)
 {
-	m_sock = new Socket( *this, false, false );
+	m_sock = new Socket( *this);
 }
 
 IServer::~IServer()
