@@ -70,7 +70,7 @@ Spring& spring()
 
 Spring::Spring() :
 	wxEvtHandler(),
-	m_process(0),
+	m_process(NULL),
 	m_running(false)
 { }
 
@@ -126,6 +126,11 @@ bool Spring::Run( IBattle& battle )
 	return LaunchEngine(executable, params);
 }
 
+bool Spring::LaunchEngine(wxArrayString& params)
+{
+	return LaunchEngine(SlPaths::GetSpringBinary(), params);
+}
+
 bool Spring::LaunchEngine(const std::string& cmd, wxArrayString& params)
 {
 	if ( m_running ) {
