@@ -121,8 +121,8 @@ class CommonUser
         int GetCpu() const { return m_cpu; }
         void SetCpu( const int& cpu ) { m_cpu = cpu; }
 
-        const std::string& GetID() const { return m_id; }
-        void SetID( const std::string& id ) { m_id = id; }
+        int GetID() const { return m_id; }
+        void SetID( int id ) { m_id = id; }
 
         UserStatus& Status() { return m_status; }
 
@@ -152,7 +152,7 @@ class CommonUser
 private:
         std::string m_nick;
         std::string m_country;
-        std::string m_id;
+        int m_id;
         int m_cpu;
         UserStatus m_status;
         UserBattleStatus m_bstatus;
