@@ -39,10 +39,14 @@ class UserList
     user_map_t::size_type GetNumUsers() const;
 
     void Nullify();
-
-  private:
+/*
+	UserList& operator= (const UserList& other) = delete;
+	UserList& operator= (const UserList&& other);
+*/
+protected:
     user_map_t m_users;
-    // The following are used as internal cache to speed up random access:
+private:
+	// The following are used as internal cache to speed up random access:
     mutable user_const_iter_t m_seek;
     mutable user_map_t::size_type m_seekpos;
 
