@@ -7,8 +7,8 @@
 #include <wx/wxchar.h>
 class wxString;
 
-wxString GetWordParam( wxString& params );
-wxString GetSentenceParam( wxString& params );
+std::string GetWordParam( wxString& params );
+std::string GetSentenceParam( wxString& params );
 long GetIntParam( wxString& params );
 bool GetBoolParam( wxString& params );
 wxString GetParamByChar( wxString& params, const wxChar& sep );
